package com.gic.store.service.outer;

import com.gic.api.base.commons.ServiceResponse;
import com.gic.bizdict.api.dto.BizdictDTO;
import com.gic.bizdict.api.service.BizdictService;
import com.gic.store.dto.StoreDictDTO;
import com.gic.store.entity.TabStoreDict;
import com.gic.store.service.StoreDictApiService;
import com.gic.store.service.StoreDictService;
import org.apache.commons.collections.CollectionUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.ArrayList;
import java.util.Date;
import java.util.List;

@Service("storeDictApiService")
public class StoreDictApiServiceImpl implements StoreDictApiService {
    @Autowired
    private StoreDictService storeDictService;
    @Autowired
    private BizdictService bizdictService;

    @Override
    public ServiceResponse<List<StoreDictDTO>> listAllStoreType(Integer enterpriseId) {
        return ServiceResponse.success(this.listAllStoreDict(enterpriseId, "storeType"));
    }

    @Override
    public ServiceResponse<List<StoreDictDTO>> listAllStoreStatus(Integer enterpriseId) {
        return ServiceResponse.success(this.listAllStoreDict(enterpriseId, "storeStatus"));
    }

    @Override
    public ServiceResponse<List<StoreDictDTO>> listStoreType(Integer enterpriseId) {
        return ServiceResponse.success(this.listStoreDict(enterpriseId, "storeType"));
    }

    @Override
    public ServiceResponse<List<StoreDictDTO>> listStoreStatus(Integer enterpriseId) {
        return ServiceResponse.success(this.listStoreDict(enterpriseId, "storeStatus"));
    }

    @Override
    public ServiceResponse saveStoreType(Integer enterpriseId, String[] storeTypeArr) {
        if(enterpriseId == null || storeTypeArr == null || (storeTypeArr != null && storeTypeArr.length==0)){
            return ServiceResponse.failure("1111", "参数错误");
        }
        List<String> listSelected = this.storeDictService.listStoreType(enterpriseId);
        for(String storeType : storeTypeArr){
            boolean isExist = false;
            for(String s : listSelected){
                if(s.equals(storeType)){
                    isExist = true;
                }
            }
            if(!isExist){
                TabStoreDict tabStoreDict = new TabStoreDict();
                tabStoreDict.setEnterpriseId(enterpriseId);
                tabStoreDict.setCreateTime(new Date());
                tabStoreDict.setValue(storeType);
                this.storeDictService.saveStoreType(tabStoreDict);
            }
        }
        return ServiceResponse.success();
    }

    @Override
    public ServiceResponse saveStoreStatus(Integer enterpriseId, String[] storeStatusArr) {
        if(enterpriseId == null || storeStatusArr == null || (storeStatusArr != null && storeStatusArr.length==0)){
            return ServiceResponse.failure("1111", "参数错误");
        }
        List<String> listSelected = this.storeDictService.listStoreType(enterpriseId);
        for(String storeStatus : storeStatusArr){
            boolean isExist = false;
            for(String s : listSelected){
                if(s.equals(storeStatus)){
                    isExist = true;
                }
            }
            if(!isExist){
                TabStoreDict tabStoreDict = new TabStoreDict();
                tabStoreDict.setEnterpriseId(enterpriseId);
                tabStoreDict.setCreateTime(new Date());
                tabStoreDict.setValue(storeStatus);
                this.storeDictService.saveStoreStatus(tabStoreDict);
            }
        }
        return ServiceResponse.success();
    }

    private List<StoreDictDTO> listAllStoreDict(Integer enterpriseId, String type){
        List<StoreDictDTO> result = new ArrayList<>();
        List<BizdictDTO> list = this.bizdictService.treeByCategoryCode(type);
        if(CollectionUtils.isNotEmpty(list)){
            List<String> listSelected = this.storeDictService.listStoreType(enterpriseId);
            for(BizdictDTO bizdictDTO : list){
                StoreDictDTO dictDTO = new StoreDictDTO();
                dictDTO.setEnterpriseId(enterpriseId);
                dictDTO.setKey(bizdictDTO.getName());
                dictDTO.setValue(bizdictDTO.getValueContent());
                for(String s : listSelected){
                    if(s.equals(bizdictDTO.getValueContent())){
                        dictDTO.setChecked(1);
                    }
                }
                result.add(dictDTO);
            }
        }
        return result;
    }

    private List<StoreDictDTO> listStoreDict(Integer enterpriseId, String type){
        List<StoreDictDTO> result = new ArrayList<>();
        List<BizdictDTO> list = this.bizdictService.treeByCategoryCode(type);
        if(CollectionUtils.isNotEmpty(list)){
            List<String> listSelected = this.storeDictService.listStoreType(enterpriseId);
            for(BizdictDTO bizdictDTO : list){
                for(String s : listSelected){
                    if(s.equals(bizdictDTO.getValueContent())){
                        StoreDictDTO dictDTO = new StoreDictDTO();
                        dictDTO.setEnterpriseId(enterpriseId);
                        dictDTO.setKey(bizdictDTO.getName());
                        dictDTO.setValue(bizdictDTO.getValueContent());
                        dictDTO.setChecked(1);
                        result.add(dictDTO);
                    }
                }
            }
        }
        return result;
    }
}
