package com.gic.store.service.outer;

import com.gic.api.base.commons.ErrorContent;
import com.gic.api.base.commons.Page;
import com.gic.api.base.commons.ServiceResponse;
import com.gic.store.service.StoreRegionApiService;
import com.gic.store.dto.StoreRegionDTO;
import com.gic.store.service.StoreRegionService;
import com.gic.store.utils.ErrorCode;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.List;

/**
 * @author zhiwj
 * @date 2019/6/24
 */
@Service("storeRegionApiService")
public class StoreRegionApiServiceImpl implements StoreRegionApiService {

    @Autowired
    private StoreRegionService storeRegionService;

    @Override
    public ServiceResponse<Integer> saveOrUpdateStoreRegion(Integer enterpriseId, String regionCode, String regionName, Integer regionId) {
        if (regionId == null) {
            // 新增
            int codeCount = storeRegionService.countByRegionCode(enterpriseId, regionCode);
            if (codeCount > 0) {
                return ServiceResponse.failure(ErrorCode.ERROR, "域code已存在");
            }
            int nameCount = storeRegionService.countByRegionName(enterpriseId, regionName, null);
            if (nameCount > 0) {
                return ServiceResponse.failure(ErrorCode.ERROR, "域name已存在");
            }
            regionId = storeRegionService.save(enterpriseId, regionCode, regionName);
        }else {
            // 修改
            int nameCount = storeRegionService.countByRegionName(enterpriseId, regionName, regionId);
            if (nameCount > 0) {
                return ServiceResponse.failure(ErrorContent.failure, "域name已存在");
            }
            storeRegionService.update(regionId, regionName);
        }
        return ServiceResponse.success(regionId);
    }

    @Override
    public ServiceResponse<Page<StoreRegionDTO>> listStoreRegion(Integer enterpriseId, String search, Integer pageNum, Integer pageSize) {
        Page<StoreRegionDTO> page = storeRegionService.listStoreRegion(enterpriseId, search, pageNum, pageSize);
        return ServiceResponse.success(page);
    }

    @Override
    public ServiceResponse<List<StoreRegionDTO>> listStoreRegion(Integer enterpriseId, String search) {
        List<StoreRegionDTO> list = storeRegionService.listStoreRegion(enterpriseId, search);
        return ServiceResponse.success(list);
    }
}
